@@ -60,7 +60,7 @@ class ToolchainYoC:
         if not toolchain_url:
             put_string("Url is empty!")
             return
-        put_string("Start to download toolchain: %s" % arch)
+        put_string("Start to download toolchain: %s. \nPlease be patient for a few minutes..." % arch)
         pattern = re.compile("(.*)\s+\-b\s+(.*)")
         branch = "master"
         match = pattern.match(toolchain_url)
