@@ -610,10 +610,13 @@ def check_remote_version():
     if os.path.isfile(ver_file):
         modified_time = os.stat(ver_file).st_mtime
         now = time.time()
-        if modified_time > now or (now - modified_time) > 3600:
+        if modified_time > now or (now - modified_time) > 4 * 3600:
             need_check = True
     else:
         need_check = True
+        aliot_dir = home_path('.aliot')
+        if not os.path.exists(aliot_dir):
+            os.mkdir(aliot_dir)
     if need_check:
         put_string("\n\nChecking latest version of aos-tools from pip server...")
         script_process = subprocess.Popen("python -m pip list --outdated", shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
